/**
* DOLLY CAM VERSION 1.1
*
* AUTHOR: Collin Brooks
* CONTACT: collin.brooks at gmail
* USAGE RIGHTS: This script may be copied, modified, distributed... whatever. Recognition would be nice but not required.
* WARRANTY: None. This script has been tested on Windows only but should work correctly on a Mac. Use at own risk.
*
* DESCRIPTION: When working with layers in 3D space, many times you want to be able to move through them
* without having to worry about the camera panning and distorting the flat layers. This script quickly sets the camera's
* auto orientation to off. This, in turn, transforms the camera into a dolly camera that is free to move on any axis but is
* parallel to the 3D layers at all times.
*
* DIRECTIONS: If nothing is selected inside the composition or no camera is selected, this script creates a new Dolly Camera
* (numbered according to how many dolly cameras the composition has). If one ore more cameras are selected when this
* script is executed, the script will alternate between each camera's auto orientation settings being off or pointing to the
* Point of Interest for that camera.
*
* LAUNCH PAD INTEGRATION: Place the included .png image in the same folder as the script and load the script in Launch Pad
*/
{
	var i,s,n, atLeastOneCamera,cameraAlreadyAdded;
	var errorMessage = "";
	var defaultCameraPrefix = "Dolly Cam ";
	var theProj = app.project;
	var theComp = theProj.activeItem;
	var camNumber = 0;
	var largestNum = 0;
	
	function addNewDollyCamera()
	{
		largestNum = 0;
		//FIRST GO THROUGH EACH LAYER AND SEE WHAT NUMBER DOLLY CAM THIS IS
		for(i=1;i<=theComp.layers.length;i++)
		{
			if((theComp.layers[i] instanceof CameraLayer)	&& theComp.layers[i].name.substr(0, defaultCameraPrefix.length) == defaultCameraPrefix)
			{
				//GET THE NUMBER
				n = parseInt(theComp.layers[i].name.substr(defaultCameraPrefix.length, theComp.layers[i].name.length));
				if(n > largestNum)
				{
					largestNum = n;
				}
			}
		}

		//INCREASE LARGEST NUMBER BY 1
		largestNum++;
		app.beginUndoGroup("Add Dolly Cam "+largestNum);//UNDO GROUP
		
		s = theComp.layers.addCamera(defaultCameraPrefix+largestNum, [0,0]);
		s.autoOrient = AutoOrientType.NO_AUTO_ORIENT;

		app.endUndoGroup();
	}
	if(theComp.selectedLayers.length > 0)
	{
	var selectedLayers = theComp.selectedLayers;
	var nothingSelected = false;
	}else{
	var nothingSelected = true;
	}

	if(theProj == null || theComp == null)
	{
		errorMessage += "Something went wrong. Make sure you have a project and composition open.\n";
	}else if(nothingSelected){
		//NOTHING IS SELECTED, ADD A CAMERA TO THE COMPOSITION
		//AND SET IT'S AUTO ORIENT TO NONE
		addNewDollyCamera();
	}else{
	app.beginUndoGroup("Set Camera To Dolly Cam");//UNDO GROUP
	atLeastOneCamera = false;
	cameraAlreadyAdded = false;
		for(i=0;i<selectedLayers.length;i++)
		{
			//CHECK TO MAKE SURE THIS IS A CAMERA LAYER
			if(selectedLayers[i] instanceof CameraLayer)
			{
				atLeastOneCamera = true;
				s = selectedLayers[i];
				if(s.autoOrient == AutoOrientType.NO_AUTO_ORIENT)
				{
					//RESET IT TO THE DEFAULT AUTO ORIENT SETTING
					s.autoOrient = AutoOrientType.CAMERA_OR_POINT_OF_INTEREST;
				}else{
					s.autoOrient = AutoOrientType.NO_AUTO_ORIENT;
				}
			}else{
				if(!atLeastOneCamera)
				{
					//A LAYER IS SELECTED BUT IT IS NOT A CAMERA LAYER
					//ADD A NEW DOLLY CAMERA
					if(!cameraAlreadyAdded)
					{
					addNewDollyCamera();
					cameraAlreadyAdded = true;
					}
				}
				writeLn("Layer "+selectedLayers[i].name+" is not a camera.");
			}
		}
	}
	
	//OUTPUT ERROR MESSAGE
	if(errorMessage != "")
	{
		alert(errorMessage);
	}

	app.endUndoGroup();//ENDD UNDO GROUP
}